## v1.1.2 (2024-12-18)

### Fix

- update min Python requirement to 3.9 and adjust dependencies for compatibility ([402aa91](https://github.com/kmnhan/cz-changeup/commit/402aa918ce549d8fed9e4c49649dc3c7e6c8ee49))

[main 8805b73] bump: version 1.1.1 → 1.1.2
 2 files changed, 7 insertions(+), 1 deletion(-)

